/*
 * Programming in Java, Jacobs University, 2015
 *
 * Create a frame (a top-level window) and add a buttons to it that
 * change the color if pressed.
 *
 * This version uses lambda functions. Unfortunately, not all listener
 * interfaces are functional interfaces so one has to resort to a
 * trick by deriving a suitable functional interface...
 */ 

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JButton;

interface WindowClosingListener extends WindowListener
{
    public default void windowActivated(WindowEvent e) {}
    public default void windowClosed(WindowEvent e) {}
    public default void windowDeactivated(WindowEvent e) {}
    public default void windowDeiconified(WindowEvent e) {}
    public default void windowIconified(WindowEvent e) {}
    public default void windowOpened(WindowEvent e) {}
}

public class ButtonPanelLambda extends JPanel
{
    public ButtonPanelLambda()
    {
	JButton yellowButton = new JButton("Yellow");
	JButton blueButton = new JButton("Blue");
	JButton redButton = new JButton("Red");

	add(yellowButton);
	add(blueButton);
	add(redButton);

	yellowButton.addActionListener(e -> this.setBackground(Color.YELLOW));
	blueButton.addActionListener(e -> this.setBackground(Color.BLUE));
	redButton.addActionListener(e -> this.setBackground(Color.RED));
    }

    public static void main(String[] args)
    {
	JFrame frame = new JFrame();
	frame.add(new ButtonPanelLambda());
	frame.pack();
	frame.addWindowListener((WindowClosingListener)(e) -> System.exit(0));
	frame.setVisible(true);
    }
}
